"use client"
import Link from "next/link";
import { usePathname, useRouter } from "next/navigation";
import Script from 'next/script'
import { data} from "@/data/data";
import { DialogComponent } from "../dialog/dialog"
import {
    Accordion,
    AccordionContent,
    AccordionItem,
    AccordionTrigger,
  } from "../../ui/accordion"
import {
    Tooltip,
    TooltipContent,
    TooltipProvider,
    TooltipTrigger,
  } from "@/components/ui/tooltip"
//image 
import img from "/public/images/team-3.jpg"
import { useEffect, useState } from "react";

import { useDispatch, useSelector } from "react-redux";
import { setToggle } from "@/lib/features/toggleSidebar/toggleSidebar";

import Styles from  "./sidebar.module.css"
import SearchInput from "../searchInput/search";
import { useTranslation } from "react-i18next";
import Image from "next/image";


function Sidebar() {
    const [isClose, setIsClose] = useState(undefined)
    const [userInfo, setUserInfo] = useState({
        username:"",
        email:"",
        photo:""
    })
    const [isOpen, setIsOpen] = useState(false)
    const pathname = usePathname() 
    const router = useRouter()
    const dispatch = useDispatch();
    const { t ,i18n } = useTranslation()
    const lang = useSelector((state=>state.langSelect.lang))
    const toggle = useSelector(state=>state.toggleSidebar.toggle)
    const langActive = i18n.language
    useEffect(()=>{
        if(localStorage.getItem("user")){
            const info =JSON.parse(localStorage.getItem("user")) 
            setUserInfo(info)
        }else{
            router.push("/login")
        } 
    },[])
    useEffect(()=>{
        if(localStorage.getItem("close")){
            const value = localStorage.getItem("close")
            if(value == "false")
                setIsClose(false)
            if(value == "true")
                setIsClose(true)

        }else{
            setIsClose(undefined)
        }
        
    },[isClose])
    
    return ( 
        <div>
            <div  className={`${isClose?Styles.closeAnimation:(isClose == false?Styles.openAnimation:Styles.sidebar)} hidden lg:block`}>

                <div className={`h-full fixed py-5  ${lang=="ar"?"pr-5":"pl-5"} ${isClose?Styles.closeAnimation:(isClose == false?Styles.openAnimation:Styles.sidebar)}`}>
                    <div className={"shadow-box radius-less bg-white h-full px-2 relative overflow-hidden"}>
                    <div className="flex justify-between py-4">
                        <h2 onClick={()=>{
                            if(isClose){
                                localStorage.setItem("close",!isClose)
                            setIsClose(!isClose)
                            dispatch(setToggle(!isClose))
                            }
                        }} className={`${isClose?"cursor-pointer":""}   font-size-xxl font-bold text-dark-color h-4.3`}>
                            {t('logo')}
                        </h2>
                        {!isClose &&<div className="button-icon" onClick={()=>{
                            localStorage.setItem("close",!isClose)
                            setIsClose(!isClose)
                            dispatch(setToggle(!isClose))
                            }}>
                            <span className="material-symbols-outlined justify-end">
                            collapse_content
                            </span>
                        </div>}
                        
                    </div>
                    <div className="my-2">
                        <SearchInput returnedvalue={(res)=>setIsOpen(res)}/>
                        {/* <InputDemo type="text" placeholder={"Search"}/> */}
                    </div>
                    <ul className={"font-size-xs text-dark-color"}>
                        {data.sidebar.map((e,i)=>{

                            
                            if(e.children){
                                
                                return (<li key={`Sidebar_${i*200}`} >
                                    <Accordion    type="single" collapsible className={`w-full ${isClose&&Styles.hideArroe} accordion-sidebar relative`}>
                                        <AccordionItem  value="item-1" className="border-0" >
                                            <AccordionTrigger  onClick={()=>{
                                                localStorage.setItem("close",false)
                                                setIsClose(false)
                                            }} className={`${isClose && Styles.hoverforTooltip} ${isClose&& Styles.centerIcon}  flex text-nowrap    py-2 mb-2 hover:no-underline  hover:bg-slate-100 radius-normal font-size-xs`} >
                                                <div className={`flex gap-3 py-0 px-1 text-dark-color justify-center  `}>
                                                    <span className={Styles.icon}> {e.icon}</span>
                                                    <span className={Styles.option}>{t(`${e.title}`)}</span>
                                                </div>
                                                {isClose&& <div className={(isClose && langActive=="ar")?Styles.tooltipDiv:((isClose && langActive=="en")?Styles.tooltipDivLeft:"")}>
                                                    {t(`${e.title}`)}
                                                </div>}
                                                
                                            </AccordionTrigger>
                                                {isClose != true && e.children.map(child=>{
                                                    const active = pathname.endsWith(child.link)
                                                    return(<AccordionContent key={`Sidebar_child_${child.title}_${i*200}`}  className={`flex items-center px-7 text-nowrap cursor-pointer  gap-3 font-size-xs ${Styles.accordionChild}`}>
                                                    {/* <Link href={child.href}> */}
                                                        <div className={active?Styles.iconChildActive:Styles.iconChild} ></div>
                                                        <span className={active?Styles.titleChildActive:Styles.titleChild}>
                                                        {t(`${child.title}`)}
                                                        </span>
                                                    
                                                    {/* </Link> */}
                                                </AccordionContent>)
                                                }
                                            )}
                                            
                                            </AccordionItem>
                                        </Accordion>
                                </li>)
                            }else{
                                const active = pathname.endsWith(e.link)
                                return(<li  key={`Sidebar_${i}_${e.key}`}>
                                    <TooltipProvider >
                                    <Tooltip>
                                        <TooltipTrigger  asChild>
                                            <Link className={active?`flex gap-3 text-nowrap   items-center text-white py-2 px-1 fill-white-active font-size-xs bg-main-color radius-normal `
                                                :`flex gap-3 py-2   text-nowrap px-1 items-center font-size-xs  radius-normal hover:bg-slate-100`} href={e.link}>
                                                <span  className={`${Styles.icon} justify-center flex`}>
                                                    {e.icon}
                                                </span>
                                                <span className={`${Styles.option}`}>
                                                    
                                                    {t(`${e.title}`)}
                                                </span>
                                            </Link>
                                        </TooltipTrigger>
                                        {isClose == true && <TooltipContent className={`bg-dark-color text-white ${langActive == "ar"?"mr-2 ":"ml-2"}`} side={langActive == "ar"?"left":"right"} >
                                        {t(`${e.title}`)}
                                        </TooltipContent>}
                                    </Tooltip>
                                    </TooltipProvider>
                            
                            </li>)
                            }
                        })}
                    </ul>
                    <div className="absolute inset-x-0 bottom-0 p-2.5 bg-white">
                        <TooltipProvider >
                            <Tooltip>
                                <TooltipTrigger  asChild>
                                    <div className={`flex gap-2 ${langActive == "ar"?"":"pl-2"} `}>
                                        <span className="material-symbols-outlined">
                                        settings
                                        </span>
                                        <div className={`font-size-xs font-semibold ${Styles.option}`}>
                                        {t(`settings`)}
                                        </div>
                                    </div>
                                </TooltipTrigger>
                                    {isClose == true && <TooltipContent className={`bg-dark-color text-white ${langActive == "ar"?"mr-2 ":"ml-2"}`} side={langActive == "ar"?"left":"right"} >
                                    {t(`settings`)}
                                </TooltipContent>}
                            </Tooltip>
                        </TooltipProvider>
                        
                        <div className={`my-3 ${Styles.option}`}>
                            <div className="h-px bg-stone-400">

                            </div>
                        </div>

                        <div className={`flex items-center gap-2.5 ${isClose&& "mt-3"}`}>
                            {/* <Avatar className="">
                                <AvatarImage src={img.src} alt="profile" />
                                <AvatarFallback>PR</AvatarFallback>
                            </Avatar> */}
                            <Image src={img.src} style={{borderRadius:"50%"}}  width={40}
                                height={40} alt="profile"  />
                            <div className={Styles.option}>
                                <h5 className="font-size-xs">{userInfo.username?userInfo.username:"Example Name"}</h5>
                                <p className="font-size-xxs">example@gmail.com</p>
                            </div>
                        
                        </div>
                        
                    </div>
                
                    </div>
                    
                    <DialogComponent returnedValue={(res)=>{setIsOpen(res)}} open={isOpen}  />
                </div> 
            </div>
        </div>
    
    
    );
}

export default Sidebar;